#include <math.h>
#include "heymsfield_westbrook_ice_fall_speed.h"

/* Returns the terminal velocity of ice particles in m s-1 using the
   formula of Heymsfield and Westbrook (J. Atmos. Sci. 2010) */
float
heymsfield_westbrook_ice_fall_speed(float rhoair, /* Air density, kg m-3 */
				   float m,      /* Particle mass, kg */
				   float D,      /* Maximum dimension, m */
				   float Ar)     /* Area ratio */
{
  static const float dynvis = 1.72e-5; /* [Pa.s] Value for 0C */
  /* 'universal' coefficients: */
  static const float delta0 = 8.0;
  const float sqrt_C0 = sqrt(0.35);
  const float pi = 4.0*atan(1.0);
  
  float Xstar = rhoair/(dynvis*dynvis)*(8.0*9.81*m)/(pi*sqrt(Ar));
  float Re = (delta0*delta0)*0.25*(sqrt(1.0+4.0*sqrt(Xstar)
				      /(delta0*delta0*sqrt_C0))-1.0)
    *(sqrt(1.0+4.0*sqrt(Xstar)/(delta0*delta0*sqrt_C0))-1.0);
  float vt =  Re*dynvis/(rhoair*D);
  return vt;

}
