/* Fortran interface to Mishchenko's T-matrix code */
extern void tmatrix_(/* In: */ 
		     double *axi, double *eps,
		     double *mrr, double *mri, double *lam,
		     /* Out: */ 
		     double *cext, double *csca, 
		     double *cradar, double *g);

/* C wrapper for Fortran code */
static inline
void
tmatrix(/* In: */
	float diameter_equivol, /* Equivolumetric diameter (m) */
	float axial_ratio,
	float refractive_index_real,
	float refractive_index_imaginary,
	float wavelength,                 /* m */
	/* Out: */
	float *extinction_cross_section,  /* m2 */
	float *scattering_cross_section,  /* m2 */
	float *backscatter_cross_section, /* m2 */
	float *asymmetry_factor)
{
  static const double ONE_OVER_FOUR_PI = 0.0795774715459477;
  double radius_equivol = diameter_equivol * 0.5;
  double eps = axial_ratio;
  double mrr = refractive_index_real;
  double mri = refractive_index_imaginary;
  double lam = wavelength;
  double cext = 0.0, csca = 0.0, cradar = 0.0, g = 0.0;

  tmatrix_(&radius_equivol, &eps, &mrr, &mri, &lam,
	   &cext, &csca, &cradar, &g);

  *extinction_cross_section = cext;
  *scattering_cross_section = csca;
  *backscatter_cross_section = cradar*ONE_OVER_FOUR_PI;
  *asymmetry_factor = g;
  return;
}
